# -*- coding: utf-8 -*-
# Generated by Django 1.9.1 on 2016-01-20 22:32
from __future__ import unicode_literals

import decimal
import django.core.serializers.json
from django.db import migrations, models
import django_pgjsonb.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='QChildTask',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(db_index=True)),
                ('parent', models.CharField(db_index=True, max_length=64)),
                ('child', models.CharField(db_index=True, max_length=64)),
            ],
            options={
                'ordering': ['created'],
            },
        ),
        migrations.CreateModel(
            name='QEvent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(db_index=True)),
                ('timestamp', models.DecimalField(blank=True, db_index=True, decimal_places=6, max_digits=30, null=True)),
                ('entity', models.CharField(db_index=True, max_length=64)),
                ('source', models.CharField(db_index=True, max_length=64)),
                ('data', django_pgjsonb.fields.JSONField(blank=True, db_index=True, db_index_options=[{}], decode_kwargs={'parse_float': decimal.Decimal}, encode_kwargs={'cls': django.core.serializers.json.DjangoJSONEncoder}, null=True)),
            ],
            options={
                'ordering': ['created'],
            },
        ),
        migrations.AlterIndexTogether(
            name='qevent',
            index_together=set([('entity', 'source', 'timestamp')]),
        ),
        migrations.AlterIndexTogether(
            name='qchildtask',
            index_together=set([('parent', 'child')]),
        ),
    ]
